@@ -55,6 +55,7 @@
 #include "pluginloader.h"
 #include "nepomukhelpers.h"
 #include "nepomukfeeder-config.h"
+#include "nepomukfeederadaptor.h"
 
 namespace Akonadi {
 
@@ -93,6 +94,7 @@ NepomukFeederAgent::NepomukFeederAgent(const QString& id) :
 
   // initialize Nepomuk
   Nepomuk::ResourceManager::instance()->init();
+  new NepomukFeederAdaptor( this );
 
   changeRecorder()->fetchCollection( true );
   changeRecorder()->itemFetchScope().setAncestorRetrieval( ItemFetchScope::Parent );
@@ -132,6 +134,12 @@ NepomukFeederAgent::~NepomukFeederAgent()
 
 }
 
+void NepomukFeederAgent::forceReindexCollection(const qlonglong id)
+{
+  CollectionFetchJob *job = new CollectionFetchJob( Collection(id), Akonadi::CollectionFetchJob::Base, this );
+  connect( job, SIGNAL(collectionsReceived(Akonadi::Collection::List)), SLOT(collectionsReceived(Akonadi::Collection::List)));
+}
+
 void NepomukFeederAgent::itemAdded(const Akonadi::Item& item, const Akonadi::Collection& collection)
 {
   kDebug() << item.id();
@@ -355,6 +363,35 @@ void NepomukFeederAgent::running(const QString &string)
   emit status( AgentBase::Running, string );
 }
 
+bool NepomukFeederAgent::isDisableIdleDetection() const
+{
+  return mIdleDetectionDisabled;
+}
+
+bool NepomukFeederAgent::queueIsEmpty()
+{
+  return mQueue.isEmpty();
+}
+
+QString NepomukFeederAgent::currentCollectionName()
+{
+  if(queueIsEmpty()) {
+    return QString();
+  } else {
+    return mQueue.currentCollection().name();
+  }
+}
+
+QStringList NepomukFeederAgent::listOfCollection() const
+{
+  QStringList names;
+  Akonadi::Collection::List listQueueCollection = mQueue.listOfCollection();
+  Q_FOREACH(const Akonadi::Collection& collection, listQueueCollection) {
+    names << collection.name();
+  }
+  return names;
+}
+
 }
 
 AKONADI_AGENT_MAIN( Akonadi::NepomukFeederAgent )
