@@ -182,48 +182,52 @@ StoreConfigIface::CollectionsByMimeType ResourceAkonadi::Private::storeCollectio
   return storeCollections;
 }
 
-void ResourceAkonadi::Private::subResourceAdded( SubResourceBase *subResource )
+void ResourceAkonadi::Private::subResourceAdded( SubResourceBase *subResourceBase )
 {
-  kDebug( 5700 ) << "id=" << subResource->subResourceIdentifier();
+  kDebug( 5700 ) << "id=" << subResourceBase->subResourceIdentifier();
 
-  SharedResourcePrivate<SubResource>::subResourceAdded( subResource );
+  SharedResourcePrivate<SubResource>::subResourceAdded( subResourceBase );
 
-  connect( subResource, SIGNAL( addresseeAdded( KABC::Addressee, QString ) ),
-           this, SLOT( addresseeAdded( KABC::Addressee, QString ) ) );
-  connect( subResource, SIGNAL( addresseeChanged( KABC::Addressee, QString ) ),
-           this, SLOT( addresseeChanged( KABC::Addressee, QString ) ) );
-  connect( subResource, SIGNAL( addresseeRemoved( QString, QString ) ),
-           this, SLOT( addresseeRemoved( QString, QString ) ) );
+  SubResource *subResource = qobject_cast<SubResource*>( subResourceBase );
 
-  connect( subResource, SIGNAL( contactGroupAdded( KABC::ContactGroup, QString ) ),
-           this, SLOT( contactGroupAdded( KABC::ContactGroup, QString ) ) );
-  connect( subResource, SIGNAL( contactGroupChanged( KABC::ContactGroup, QString ) ),
-           this, SLOT( contactGroupChanged( KABC::ContactGroup, QString ) ) );
-  connect( subResource, SIGNAL( contactGroupRemoved( QString, QString ) ),
-           this, SLOT( contactGroupRemoved( QString, QString ) ) );
+  connect( subResource, SIGNAL(addresseeAdded(KABC::Addressee,QString)),
+           this, SLOT(addresseeAdded(KABC::Addressee,QString)) );
+  connect( subResource, SIGNAL(addresseeChanged(KABC::Addressee,QString)),
+           this, SLOT(addresseeChanged(KABC::Addressee,QString)) );
+  connect( subResource, SIGNAL(addresseeRemoved(QString,QString)),
+           this, SLOT(addresseeRemoved(QString,QString)) );
 
-  emit mParent->signalSubresourceAdded( mParent, QLatin1String( "contact" ), subResource->subResourceIdentifier() );
+  connect( subResource, SIGNAL(contactGroupAdded(KABC::ContactGroup,QString)),
+           this, SLOT(contactGroupAdded(KABC::ContactGroup,QString)) );
+  connect( subResource, SIGNAL(contactGroupChanged(KABC::ContactGroup,QString)),
+           this, SLOT(contactGroupChanged(KABC::ContactGroup,QString)) );
+  connect( subResource, SIGNAL(contactGroupRemoved(QString,QString)),
+           this, SLOT(contactGroupRemoved(QString,QString)) );
+
+  emit mParent->signalSubresourceAdded( mParent, QLatin1String( "contact" ), subResourceBase->subResourceIdentifier() );
 }
 
-void ResourceAkonadi::Private::subResourceRemoved( SubResourceBase *subResource )
+void ResourceAkonadi::Private::subResourceRemoved( SubResourceBase *subResourceBase )
 {
-  kDebug( 5700 ) << "id=" << subResource->subResourceIdentifier();
+  kDebug( 5700 ) << "id=" << subResourceBase->subResourceIdentifier();
 
-  SharedResourcePrivate<SubResource>::subResourceRemoved( subResource );
+  SharedResourcePrivate<SubResource>::subResourceRemoved( subResourceBase );
 
-  disconnect( subResource, SIGNAL( addresseeAdded( KABC::Addressee, QString ) ),
-              this, SLOT( addresseeAdded( KABC::Addressee, QString ) ) );
-  disconnect( subResource, SIGNAL( addresseeChanged( KABC::Addressee, QString ) ),
-              this, SLOT( addresseeChanged( KABC::Addressee, QString ) ) );
-  disconnect( subResource, SIGNAL( addresseeRemoved( QString, QString ) ),
-              this, SLOT( addresseeRemoved( QString, QString ) ) );
+  SubResource *subResource = qobject_cast<SubResource*>( subResourceBase );
 
-  disconnect( subResource, SIGNAL( contactGroupAdded( KABC::ContactGroup, QString ) ),
-              this, SLOT( contactGroupAdded( KABC::ContactGroup, QString ) ) );
-  disconnect( subResource, SIGNAL( contactGroupChanged( KABC::ContactGroup, QString ) ),
-              this, SLOT( contactGroupChanged( KABC::ContactGroup, QString ) ) );
-  disconnect( subResource, SIGNAL( contactGroupRemoved( QString, QString ) ),
-              this, SLOT( contactGroupRemoved( QString, QString ) ) );
+  disconnect( subResource, SIGNAL(addresseeAdded(KABC::Addressee,QString)),
+              this, SLOT(addresseeAdded(KABC::Addressee,QString)) );
+  disconnect( subResource, SIGNAL(addresseeChanged(KABC::Addressee,QString)),
+              this, SLOT(addresseeChanged(KABC::Addressee,QString)) );
+  disconnect( subResource, SIGNAL(addresseeRemoved(QString,QString)),
+              this, SLOT(addresseeRemoved(QString,QString)) );
+
+  disconnect( subResource, SIGNAL(contactGroupAdded(KABC::ContactGroup,QString)),
+              this, SLOT(contactGroupAdded(KABC::ContactGroup,QString)) );
+  disconnect( subResource, SIGNAL(contactGroupChanged(KABC::ContactGroup,QString)),
+              this, SLOT(contactGroupChanged(KABC::ContactGroup,QString)) );
+  disconnect( subResource, SIGNAL(contactGroupRemoved(QString,QString)),
+              this, SLOT(contactGroupRemoved(QString,QString)) );
 
   // block scope for BoolGuard
   {
@@ -231,7 +235,7 @@ void ResourceAkonadi::Private::subResourceRemoved( SubResourceBase *subResource
 
     QMap<QString, QString>::iterator it = mUidToResourceMap.begin();
     while ( it != mUidToResourceMap.end() ) {
-      if ( it.value() == subResource->subResourceIdentifier() ) {
+      if ( it.value() == subResourceBase->subResourceIdentifier() ) {
         const QString uid = it.key();
 
         mChanges.remove( uid );
@@ -249,7 +253,7 @@ void ResourceAkonadi::Private::subResourceRemoved( SubResourceBase *subResource
     }
   }
 
-  emit mParent->signalSubresourceRemoved( mParent, QLatin1String( "contact" ), subResource->subResourceIdentifier() );
+  emit mParent->signalSubresourceRemoved( mParent, QLatin1String( "contact" ), subResourceBase->subResourceIdentifier() );
 
   emit mParent->addressBook()->emitAddressBookChanged();
 }
