@@ -473,6 +473,8 @@ void DavGroupwareResource::onRetrieveCollectionsFinished( KJob *job )
 
   const DavCollection::List davCollections = fetchJob->collections();
 
+  QSet<QString> parentMimeTypes = QSet<QString>::fromList( mDavCollectionRoot.contentMimeTypes() );
+
   foreach ( const DavCollection &davCollection, davCollections ) {
     if ( mReplayCache.hasReplayEntries( davCollection.url() ) )
       mReplayCache.flush( davCollection.url() );
@@ -522,6 +524,7 @@ void DavGroupwareResource::onRetrieveCollectionsFinished( KJob *job )
     if ( contentTypes & DavCollection::Journal )
       mimeTypes << KCalCore::Journal::journalMimeType();
 
+    parentMimeTypes += QSet<QString>::fromList( mimeTypes );
     collection.setContentMimeTypes( mimeTypes );
     setCollectionIcon( collection /*by-ref*/ );
 
@@ -552,6 +555,12 @@ void DavGroupwareResource::onRetrieveCollectionsFinished( KJob *job )
     collections << collection;
   }
 
+  // Set the list of possible mimetypes on the root collection to be the union
+  // of all the possible mimetypes on all the child collections. This is
+  // necessary in order for the root collection to be displayed in certain
+  // views.
+  collections[0].setContentMimeTypes( parentMimeTypes.values() );
+
   collectionsRetrieved( collections );
 }
 
